# -*- coding: utf-8 -*-
"""
astLib - python astronomy modules

(c) 2007-2012 Matt Hilton

U{http://astlib.sourceforge.net}

See the README file for information on usage and installation.
See the LICENSE file for information on distribution.

"""

__all__=['astCalc', 'astCoords', 'astImages', 'astPlots', 'astStats', 'astWCS', 'astSED']
__version__ = '0.6.1'
